# This file contains the code to analize the level of infection (parasite load) of 
# Crithidia bombi in bumble bee colonies

rm(list=ls())
# set up working directory. Edit as needed
setwd("~/Dropbox/EEID/Within Colony/Dryad/CSV")

# packages needed
library(glmmTMB); library(car); library(emmeans)
library(plyr); library(multcompView); library(DHARMa)

source("emmeans.R") # allow glmmTMB to communicate with emmeans. This file MUST be in the working directory


count <- read.csv("BB_crithidia.csv") 
count$week = as.factor(count$week)
count$samplingF = as.factor(count$sampling) # turn sampling as a factor in a new variable
count$Bee_ID = as.factor(count$Bee_ID)
count$date = as.Date(count$date, format = "%m/%d/%y")
count$colony = as.factor(count$colony)
count$cell_con = as.integer(count$cell_count*50) # calculate the concentration of cell per microliter
count <- count[-c(1179),] # delete a row with missing values
count <- count[-c(337),] # delete outlier

# make a dataset with data ONLY of infected bees
countI <- subset(count, infected_status >0)  

# create a data frame with data starting in sampling 9 (week 5), due to that
# in previous weeks there were almost no bees infected in the Low (1%) treatment
countI2 <- subset(countI, sampling >8)


# models:

# Model with interactions and wings
ModelF1 <- glmmTMB(cell_con ~ treatment * week +wings +(1|colony/Bee_ID), 
                  family = "nbinom2",data= countI2)

# model without wings
ModelF2 <- glmmTMB(cell_con ~ treatment * week +(1|colony/Bee_ID), 
                  family = "nbinom2",data= countI2)

# model without random effect
ModelF3 <- glmmTMB(cell_con ~ treatment * week, 
                   family = "nbinom2",data= countI2)

# Model including number of bees in the colony
ModelF4 <- glmmTMB(cell_con ~ treatment * week+worker_colony +(1|colony/Bee_ID), 
                   family = "nbinom2",data= countI2)

# model without nested random effect
ModelF5 <- glmmTMB(cell_con ~ treatment * week +(1|colony), 
                   family = "nbinom2",data= countI2)

# model without interaction
ModelF6 <- glmmTMB(cell_con ~ treatment +week+(1|colony), 
                   family = "nbinom2",data= countI2)

# model without week
ModelF7 <- glmmTMB(cell_con ~ treatment +(1|colony), 
                   family = "nbinom2",data= countI2)


# compare models
anova(ModelF1, ModelF2, ModelF3, ModelF4, ModelF5, ModelF6, ModelF7)
AIC(ModelF1, ModelF2, ModelF3, ModelF4, ModelF5, ModelF6, ModelF7)
# models 6 & 7 had the lower AIC, and there is not significant difference between those models
# so we select model 7 because it is simpler than model 6

# check the fit of model 7
system.time(sr <- simulateResiduals(ModelF7))
plot(sr)

summary(ModelF7)
Anova(ModelF7)

###############
# BEST MODEL: 7
##############