# This file contains the code to analize the prevalence (% infected bees/colony) of 
# Crithidia bombi in bumble bee colonies

rm(list=ls())
# set up working directory. Edit as needed
setwd("~/Dropbox/EEID/Within Colony/Dryad/CSV")

library(Rmisc); library(glmmTMB); library(car); library(DHARMa); 
library(emmeans); library(plyr); library(multcompView)

source("emmeans.R") # allow glmmTMB to communicate with emmeans. This file must be on the WD

count <- read.csv("BB_crithidia.csv") 
count$week = as.factor(count$week)
count$Bee_ID = as.factor(count$Bee_ID)
count$date = as.Date(count$date, format = "%m/%d/%y")
count$colony = as.factor(count$colony)
count$samplingF = as.factor(count$sampling)
count <- count[-c(1179),] # eliminate a row with missing values
head(count)

# don't include  data from the firt week (sampling 1 and 2)
count2 <- subset(count, sampling >2)


############################
# LOGISTIC REGRESION

# full model with interaction 
logi_1<- glmmTMB(infected_status~  treatment*week+worker_colony +(1|colony),
                 weights=sampling, family = "binomial",  data = count2)

# full model without the "weight" parameter
logi_2<- glmmTMB(infected_status~  treatment*week+worker_colony +(1|colony),
                 family = "binomial",  data = count2)

# model without interaction
logi_3<- glmmTMB(infected_status~  treatment+week+worker_colony+(1|colony),
                 family = "binomial",  data = count2)

# model with interaction but without workers/colony
logi_4<- glmmTMB(infected_status~  treatment*week+(1|colony),
                  family = "binomial",  data = count2)

# full model without random effect and wings
logi_5<- glmmTMB(infected_status~  treatment*week+worker_colony,
                family = "binomial",  data = count2)

# full model without random effect
logi_6<- glmmTMB(infected_status~  treatment*week+worker_colony+wings,
                 family = "binomial",  data = count2)

# model with only main effects and colony as random effect
logi_7<- glmmTMB(infected_status~  treatment+week+(1|colony),
                 family = "binomial",  data = count2)


anova(logi_7, logi_6, logi_5,logi_4, logi_3, logi_2)
anova(logi_2,logi_4)

summary(logi_4)
Anova(logi_4)

drop1(logi_4, test = "Chisq")

## test fit of the model. QQplot and residual 
system.time(sr <- simulateResiduals(logi_4))
plot(sr)

#############
# BEST MODEL: 4
##############


## multiple comparisons

pigs.emm.s <- emmeans(logi_4, "treatment")
pairs(pigs.emm.s)

# comparison between sampling points for each treatment
Lsm2<-emmeans(logi_4, ~ week | treatment, adjust="tukey") 
(Pairs2<-contrast(Lsm2, "pairwise") )
 
# comparison between treamtnets for each sampling point 
Lsm3<-emmeans(logi_4, ~  treatment|week , adjust="tukey") 
(Pairs3<-contrast(Lsm3, "pairwise")) 







