# This file contains the code to analize the level of infection (parasite load) of 
# Nosema ceranae in honey bee colonies

rm(list=ls())
# set up working directory. Edit as needed
setwd("~/Dropbox/EEID/Within Colony/Dryad/CSV")

library(glmmTMB); library(car); library(DHARMa); library(emmeans)
library(plyr); library(multcompView)

source("emmeans.R") # allow glmmTMB to communicate with emmeans. The file must be in the WD

count_hb <- read.csv("HB_nosema.csv") 
count_hb <- count_hb[-c(253),] # eliminate a row with missing values

# make a dataset with ONLY the data of infected bees
count_hb_i <- subset(count_hb, Nosema_Presence >0) 
# round up the nosema concentration
count_hb_i[,19] <-round(count_hb_i[,19],0) 
# subset data without the first 2 weeks of sampling
count_hb_i_m <- subset(count_hb_i, week >2)


# Models

# model without interaction
model_hb<- glmmTMB(concentration~ treatment + factor(week) + wing + (1|hive_number), 
                   family = "nbinom2", data = count_hb_i_m)

# model WITH interaction
model_hb_2<- glmmTMB(concentration~ treatment * factor(week) + wing +(1|hive_number), 
                   family = "nbinom2", data = count_hb_i_m)

# model WITH interaction and no random effect
model_hb_3<- glmmTMB(concentration~ treatment + factor(week) +wing, 
                     family = "nbinom2", data = count_hb_i_m)

# full model plus ZI parameter
model_hb_4<- glmmTMB(concentration~ treatment * factor(week) + wing +(1|hive_number), 
                     zi=~1, family = "nbinom2", data = count_hb_i_m)

# model with no wings
model_hb_5<- glmmTMB(concentration~ treatment * factor(week) +(1|hive_number), 
                     family = "nbinom2", data = count_hb_i_m)

# model with no wings and no interaction
model_hb_6<- glmmTMB(concentration~ treatment + factor(week) +(1|hive_number), 
                     family = "nbinom2", data = count_hb_i_m)


# compare models
anova(model_hb, model_hb_2, model_hb_3, model_hb_4, model_hb_5, model_hb_6)
anova(model_hb_5, model_hb_2)

drop1(model_hb_2, test = "Chisq") 

## test fit of the model.QQplot and residual 
system.time(sr <- simulateResiduals(model_hb_2))
testDispersion(sr) # test for overdispersion. If it is signifincat it is overdispersed
plot(sr)

summary(model_hb_2)
Anova(model_hb_2)

###########
# BEST MODEL: 2
###########


## multiple comparisons
pigs.emm.s <- emmeans(model_hb_2, "treatment")
pairs(pigs.emm.s)

# it is posible to add more than one factor by  ~samplingF*treatment
Lsm<-emmeans(model_hb_2, ~factor(week) | treatment, adjust="tukey") # them | make two groups of comparison, one for each level of Treatment
(Pairs<-contrast(Lsm, "pairwise") )

# comparison between treatments for each sampling point
Lsm2<-emmeans(model_hb_2, ~ treatment | factor(week), adjust="tukey") 
(Pairs2<-contrast(Lsm2, "pairwise") )





