# This file contains the code to analize the prevalence (% of infected workers/colony) of 
#  Nosema ceranae in honey bee colonies

rm(list=ls())
# set up working directory. Edit as needed
setwd("~/Dropbox/EEID/Within Colony/Dryad/CSV")

# packages needed
library(glmmTMB); library(car); library(emmeans)
library(plyr); library(multcompView); library(DHARMa)

source("emmeans.R") # allow glmmTMB to communicate with emmeans. This file MUST be in the working directory

count_hb <- read.csv("HB_nosema.csv") 
count_hb <- count_hb[-c(253),] # eliminate a row with outliwer
count_hb$Bee_number = as.factor(count_hb$Bee_number)
count_hb$hive_number = as.factor(count_hb$hive_number)
count_hb$week = as.factor(count_hb$week)

# subsete data without the first week of sampling
count_hb2 <- subset(count_hb, as.numeric(week) >1)

# Models

# full model
logi_hb_2<- glmmTMB(Nosema_above_one ~  treatment*week+(1|hive_number),
                     family = "binomial",  data = count_hb)

# model with no interaction
logi_hb_3<- glmmTMB(Nosema_above_one ~  treatment+week+(1|hive_number),
                    family = "binomial",  data = count_hb)

# model with no interaction and no random effect
logi_hb_4<- glmmTMB(Nosema_above_one ~  treatment+week,
                    family = "binomial",  data = count_hb)

# model with no treamtnet
logi_hb_5<- glmmTMB(Nosema_above_one ~  week+(1|hive_number),
                    family = "binomial",  data = count_hb)

# Full model with wings
logi_hb_6<- glmmTMB(Nosema_above_one ~  treatment*week+wing+(1|hive_number),
                    family = "binomial",  data = count_hb)


anova( logi_hb_3, logi_hb_4, logi_hb_5, logi_hb_6)
anova(logi_hb_5, logi_hb_3)

drop1(logi_hb_5, test = "Chisq")

## test fit of the model. QQplot and residual 
system.time(sr <- simulateResiduals(logi_hb_5))
plot(sr)

summary(logi_hb_5)
Anova(logi_hb_5)

###############
# BEST MODEL: 5
###############

## multiple comparisons
# contrast
pigs.emm.s <- emmeans(logi_hb_5, "week")
pairs(pigs.emm.s)



